/*==================================================================
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corp. 2002.  All rights reserved.
 *
 * US Government Users Restricted Rights - Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM
 * Corp.
 *
 * DISCLAIMER OF WARRANTIES.  The following [enclosed] code is
 * sample code created by IBM Corporation.  This sample code is
 * not part of any standard or IBM product and is provided to you
 * solely for the purpose of assisting you in the development of
 * your applications.  The code is provided "AS IS", without
 * warranty of any kind.  IBM shall not be liable for any damages
 * arising out of your use of the sample code, even if they have
 * been advised of the possibility of such damages.
 *===============================================================*/
package com.ibm.portal.struts.example.tiles.actions;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.struts.action.Action;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.commons.beanutils.PropertyUtils;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;
import javax.servlet.http.HttpServletResponse;

import com.ibm.portal.struts.example.tiles.AccountBean;
import com.ibm.portal.struts.example.tiles.AccountsBean;
import com.ibm.portal.struts.example.tiles.Constants;

/**
 * The Action will validate the pin and then access the back end system
 * to get the account information. Actually the Action just makes up the
 * information
 */
public class ValidatePinAction extends Action
{
   /**
     * The <code>Log</code> instance for this application.
     */
   private Log log = 
      LogFactory.getLog(this.getClass ());
   
   /**
    * This execute method validates the pin, if successful then the account
    * information is obtained and forwards to success, other wise forward
    * to failure
    * 
    * @param mapping the action mapping
    * @param form the action form
    * @param request the request object
    * @param response the response object
    */
   public ActionForward execute(ActionMapping mapping,
                                 ActionForm form,
                                 HttpServletRequest request,
                                 HttpServletResponse response)
   throws Exception 
   {

      log.debug("ValidatePinAction");

      String pin = (String)
            PropertyUtils.getSimpleProperty(form, "pin");

      // this check would really go to a back end system, but for this example
      // only 1234 works.
      ActionForward forward = mapping.findForward(Constants.FAILURE);
      if ( "1234".equals(pin) )
      {
         // need to make up some account information
         AccountsBean accountsBean = new AccountsBean();

         HttpSession session = request.getSession();
         session.setAttribute(Constants.ACCOUNT_INFORMATION, accountsBean );
                  
         // uncomment the following line for a simple global exceptions test
         //accountsBean = null;
         accountsBean.reset();

         // add a savings account
         AccountBean savingsAccountBean = new AccountBean();
         savingsAccountBean.setAccountName("Savings");
         savingsAccountBean.setAccountBalance("1001.34");
         accountsBean.addAccount( savingsAccountBean ); 
         
         // add a checking account as well.
         AccountBean checkingAccountBean = new AccountBean();
         checkingAccountBean.setAccountName("Checking");
         checkingAccountBean.setAccountBalance("1341.34");
         accountsBean.addAccount( checkingAccountBean ); 
         
         forward = mapping.findForward(Constants.SUCCESS);
      } 
      return forward;                                 

   }
}
