package com.ibm.etools.portal.portletexamples.bookmark.jsr;

import java.io.*;
import javax.portlet.*;

public class BookmarkPortlet extends GenericPortlet {

	public static final String JSP_FOLDER    = "/jsp/";    	// JSP folder name
	public static final String VIEW_JSP      = "View";      // JSP file name to be rendered on the view mode
	public static final String EDIT_JSP      = "Edit";      // JSP file name to be rendered on the edit mode

	private PortletContext context;

	public void init(PortletConfig config) throws PortletException {
		super.init(config);
		context = config.getPortletContext();
	}

	public void doView(RenderRequest request, RenderResponse response)
		throws PortletException, IOException {

		// Set the MIME type for the render response
		response.setContentType(request.getResponseContentType());

		// Invoke the JSP to render
		PortletRequestDispatcher rd = getPortletContext().getRequestDispatcher(getJspFilePath(request, VIEW_JSP));
		rd.include(request, response);
	}

	public void doEdit(RenderRequest request, RenderResponse response)
		throws PortletException, IOException {

		// Set the MIME type for the render response
		response.setContentType(request.getResponseContentType());
		PortletURL setUrl = response.createActionURL();
		setUrl.setPortletMode(PortletMode.EDIT);
		setUrl.setParameter("set", "set");
		request.setAttribute("setUrl", setUrl.toString());

		PortletURL backUrl = response.createRenderURL();
		backUrl.setPortletMode(PortletMode.VIEW);
		request.setAttribute("backUrl", backUrl.toString());

		// Invoke the JSP to render
		PortletRequestDispatcher rd = getPortletContext().getRequestDispatcher(getJspFilePath(request, EDIT_JSP));
		rd.include(request, response);
	}

	public void processAction(ActionRequest request, ActionResponse response)
		throws PortletException, IOException {

		try {
			String resetName = request.getParameter("reset");
			if (resetName != null) {
				PortletPreferences prefs = request.getPreferences();
				prefs.reset(resetName);
				prefs.store();
			}
		} catch (IOException ioe) {
			context.log(
				"An IO error occured when trying to reset a bookmark.");
		} catch (PortletException pe) {
			context.log(
				"A portlet exception was thrown when trying to reset a bookmark.");
		}

		try {
			String add = request.getParameter("set");
			if (add != null) {
				PortletPreferences prefs = request.getPreferences();
				prefs.setValue(
					request.getParameter("name"),
					request.getParameter("value"));
				prefs.store();
			}
		} catch (IOException ioe) {
			context.log("An IO error occured when trying to set a bookmark.");
		} catch (PortletException pe) {
			context.log(
				"A portlet exception was thrown when trying to set a bookmark.");
		}
	}

	/**
	 * Returns JSP file path.
	 * 
	 * @param request Render request
	 * @param jspFile JSP file name
	 * @return JSP file path
	 */
	private static String getJspFilePath(RenderRequest request, String jspFile) {
		String markup = request.getProperty("wps.markup");
		if( markup == null )
			markup = getMarkup(request.getResponseContentType());
		return JSP_FOLDER+markup+"/"+jspFile+"."+getJspExtension(markup);
	}
	
	/**
	 * Convert MIME type to markup name.
	 * 
	 * @param contentType MIME type
	 * @return Markup name
	 */
	private static String getMarkup(String contentType) {
		if( "text/vnd.wap.wml".equals(contentType) )
			return "wml";
		return "html";
	}

	/**
	 * Returns the file extension for the JSP file
	 * 
	 * @param markupName Markup name
	 * @return JSP extension
	 */
	private static String getJspExtension(String markupName) {
		return "jsp";
	}

}
