/* @copyright module */
/*                                                                            */
/*  DISCLAIMER OF WARRANTIES:                                                 */
/*  -------------------------                                                 */
/*  The following [enclosed] code is sample code created by IBM Corporation.  */
/*  This sample code is provided to you solely for the purpose of assisting   */
/*  you in the development of your applications.                              */
/*  The code is provided "AS IS", without warranty of any kind. IBM shall     */
/*  not be liable for any damages arising out of your use of the sample code, */
/*  even if they have been advised of the possibility of such damages.        */
package com.ibm.etools.portal.portletexamples.cooperative.legacy;

import java.io.IOException;
import java.text.MessageFormat;
import java.util.Calendar;
import java.util.GregorianCalendar;

import org.apache.jetspeed.portlet.PortletAdapter;
import org.apache.jetspeed.portlet.PortletException;
import org.apache.jetspeed.portlet.PortletPageListener;
import org.apache.jetspeed.portlet.PortletRequest;
import org.apache.jetspeed.portlet.PortletResponse;
import org.apache.jetspeed.portlet.event.ActionEvent;
import org.apache.jetspeed.portlet.event.ActionListener;

import com.ibm.wps.logging.LogManager;
import com.ibm.wps.logging.Logger;

/*
 *
 * This portlet will get data from a mock database and 
 * display orders for a month 
 *
 */ 
public class OrderMonthPortlet 
extends PortletAdapter
implements ActionListener, PortletPageListener {
    private static final String PREFIX = "SHIPPINGORDERS";
    public static final String ACTION_NAME = PREFIX + "actionName";
    public static final String ORDERS_FOR_MONTH = PREFIX + "ordersForMonth";
    public static final String MONTH_ENTRY = PREFIX + "monthEntry";
    public static final String ORDER_MONTH_BEAN = PREFIX + "orderMonthBean";
    public static final String MONTH = PREFIX + "month";
    public static final String NAMESPACE =
    "http://www.ibm.com/etools/portal/portletexamples/cooperative/legacy";
    public static final String NLSFILENAME = "nls.shippingc2a";

    private static Logger log = LogManager.getLogManager().getLogger(OrderMonthPortlet.class);

    private static final String[] monthString = {"January","February","March","April","May","June","July","August","September","October","November","December"};

    public void beginPage(PortletRequest request,
                          PortletResponse response) {
    }

    public void endPage(PortletRequest request,
                        PortletResponse response) {
    }


    /**
     * Process the portlet request, according to action 
     * to create protlet response
     *
     * @param request The Portlet request we are processing
     * @param response The Portlet response we are creating
     *
     * @exception PortletException,IOException
     */

    public void doView(PortletRequest request, PortletResponse response) 
    throws PortletException,IOException
    {

        if ( log.isLogging(Logger.TRACE_MEDIUM) ) {
            log.entry(Logger.TRACE_MEDIUM, "doView");
        }
        OrderMonthBean omb = new OrderMonthBean();
        try {

            String action = (String) request.getSession().getAttribute(ACTION_NAME);
            if ( log.isLogging(Logger.TRACE_HIGH) ) {
                log.text(Logger.TRACE_HIGH, "doView", "action = " + action);
            }
            request.setAttribute(ORDER_MONTH_BEAN, omb);

            if (action != null && action.equals(MONTH_ENTRY)) {

                //Show initial page
                String actionURI = ShippingUtils.createSimpleActionURI(ORDERS_FOR_MONTH, response);
                omb.setActionURI(actionURI);
                getPortletConfig().getContext().include("/jsp/html/OrderMonthEntry.jsp",
                                                        request, response);

            } else if (action == null || action.equals(ORDERS_FOR_MONTH)) {


                String month = null;
                if (action == null) {
                    // Get the value of the constant Parameter 
                    month = (String) request.getParameter("defaultMonth"); 
                    if (month == null) {
                        Calendar calendar = new GregorianCalendar();
                        month = monthString[calendar.get(Calendar.MONTH)];
                    }
                } else {
                    month = (String) request.getSession().getAttribute(MONTH);
                }
                if ( log.isLogging(Logger.TRACE_HIGH) ) {
                    log.text(Logger.TRACE_HIGH, "doView", "month = " + month);
                }
                Order orderList[] = ShippingDB.getOrders(month);

                String actionURI = ShippingUtils.createSimpleActionURI(ORDERS_FOR_MONTH, response);
                omb.setActionURI(actionURI);

                if (orderList != null) {
                    omb.setOrders(orderList);
                    omb.setMonth(ShippingDB.normalizeMonth(month));
                    getPortletConfig().getContext().include("/jsp/html/OrderMonthView.jsp",
                                                            request, response);
                } else {
                    //Print error page
                    if ( log.isLogging(Logger.TRACE_HIGH) ) {
                        log.text(Logger.TRACE_HIGH, "doView", "No orders found.");
                    }
                    String msg = MessageFormat.format(Messages.getString("ERR_OrderMonthPortlet.0"), new String[] {month}); //$NON-NLS-1$
                    omb.setErrorMessage(msg);
                    getPortletConfig().getContext().include("/jsp/html/OrderMonthError.jsp", request, response);
                }
            }

        } catch (Exception exc) {
            //Exception; print error page 
            request.setAttribute(ORDER_MONTH_BEAN, omb);
            omb.setErrorMessage(Messages.getString("ERR_OrderMonthPortlet.1")); //$NON-NLS-1$
            getPortletConfig().getContext().include("/jsp/html/OrderMonthError.jsp", request, response);
            if ( log.isLogging(Logger.ERROR) ) {
                log.text(Logger.ERROR, "doView", "unexpected exception", exc);
            }
        }
        if ( log.isLogging(Logger.TRACE_MEDIUM) ) {
            log.exit(Logger.TRACE_MEDIUM, "doView");
        }
    }

    /**
     * Process ActionEvent, according to action name
     * to set request attribute
     *
     * @param event The ActionEvent we are processing
     *
     */

    public void actionPerformed (ActionEvent event)
    {
        if ( log.isLogging(Logger.TRACE_MEDIUM) ) {
            log.entry(Logger.TRACE_MEDIUM, "actionPerformed");
        }
        String actionName = event.getActionString();
        if ( log.isLogging(Logger.TRACE_HIGH) ) {
            log.text(Logger.TRACE_HIGH, "actionPerformed", "actionName = " + actionName);
        }
        PortletRequest request = event.getRequest();


        if (actionName.equals(ORDERS_FOR_MONTH)) {
            request.getSession().setAttribute(ACTION_NAME, ORDERS_FOR_MONTH);
            request.getSession().setAttribute(MONTH, request.getParameter(MONTH));
        } else if (actionName.equals(MONTH_ENTRY)) {
            request.getSession().setAttribute(ACTION_NAME, MONTH_ENTRY);
        }

        if ( log.isLogging(Logger.TRACE_MEDIUM) ) {
            log.exit(Logger.TRACE_MEDIUM, "actionPerformed");
        }
    }
}

