/* @copyright module */
/*                                                                            */
/*  DISCLAIMER OF WARRANTIES:                                                 */
/*  -------------------------                                                 */
/*  The following [enclosed] code is sample code created by IBM Corporation.  */
/*  This sample code is provided to you solely for the purpose of assisting   */
/*  you in the development of your applications.                              */
/*  The code is provided "AS IS", without warranty of any kind. IBM shall     */
/*  not be liable for any damages arising out of your use of the sample code, */
/*  even if they have been advised of the possibility of such damages.        */
package com.ibm.etools.portal.portletexamples.cooperative.legacy;

import java.io.IOException;
import java.text.MessageFormat;

import org.apache.jetspeed.portlet.PortletAdapter;
import org.apache.jetspeed.portlet.PortletException;
import org.apache.jetspeed.portlet.PortletRequest;
import org.apache.jetspeed.portlet.PortletResponse;
import org.apache.jetspeed.portlet.event.ActionEvent;
import org.apache.jetspeed.portlet.event.ActionListener;

import com.ibm.wps.logging.LogManager;
import com.ibm.wps.logging.Logger;

/*
 *
 * This portlet will get data from a mock database and 
 * display tracking detail or routing detail of a order 
 *
 */ 
public class TrackingPortlet 
extends PortletAdapter 
implements ActionListener {

    private static final String PREFIX = "";
    public static final String ACTION_NAME = PREFIX + "actionName";
    public static final String TRACKING_DETAILS = PREFIX + "trackingDetails";
    public static final String ROUTING_DETAILS = PREFIX + "routingDetails";
    public static final String TRACKING_ID_ENTRY = PREFIX + "trackingIdEntry";
    public static final String TRACKING_ID = PREFIX + "trackingId";
    public static final String TRACKING_DETAIL_BEAN = PREFIX + "trackingDetailBean";
    public static final String CUSTOMER_NAME = PREFIX + "customerName";

    private static Logger log = LogManager.getLogManager().getLogger(TrackingPortlet.class);

    /**
     * Process the portlet request, according to action 
     * to create protlet response
     *
     * @param request The Portlet request we are processing
     * @param response The Portlet response we are creating
     *
     * @exception PortletException,IOException
     */
    public void doView(PortletRequest request, PortletResponse response)
    throws PortletException,IOException
    {
        if (log.isLogging(Logger.TRACE_MEDIUM)) {
            log.entry(Logger.TRACE_MEDIUM, "doView");
        }
        TrackingDetailBean tdb = new TrackingDetailBean();
        try {

            String action = (String) request.getPortletSession().getAttribute(ACTION_NAME);
            if (log.isLogging(Logger.TRACE_MEDIUM)) {
                log.text(Logger.TRACE_MEDIUM, "doView", "action = " + action);
            }
            request.setAttribute(TRACKING_DETAIL_BEAN, tdb);

            if (action == null || action.equals(TRACKING_ID_ENTRY)) {
                //Show initial page
                String actionURI = ShippingUtils.createSimpleActionURI(TRACKING_DETAILS, response);
                tdb.setActionURI(actionURI);
                getPortletConfig().getContext().include("/jsp/html/TrackingDetailEntry.jsp",
                                                        request, response);
            } else if (action.equals(TRACKING_DETAILS) || action.equals(ROUTING_DETAILS)) {

                String actionURI = ShippingUtils.createSimpleActionURI(TRACKING_DETAILS, response);

                tdb.setActionURI(actionURI);
                String rdActionURI = ShippingUtils.createSimpleActionURI(ROUTING_DETAILS, response);
                tdb.setRoutingDetailActionURI(rdActionURI);
                String trackingId = (String) request.getPortletSession().getAttribute(TRACKING_ID);

                if (log.isLogging(Logger.TRACE_MEDIUM)) {
                    log.text(Logger.TRACE_MEDIUM, "doView", "trackingId = " + trackingId);
                }
                TrackingDetail td = ShippingDB.getTrackingDetail(trackingId);
                if (td != null) {
                    tdb.setTrackingDetail(td);
                    if (action.equals(TRACKING_DETAILS))
                        getPortletConfig().getContext().include("/jsp/html/TrackingView.jsp",
                                                                request, response);
                    else if (action.equals(ROUTING_DETAILS)) {
                        if (td.getRouteSegments() != null) {
                            getPortletConfig().getContext().include("/jsp/html/RoutingView.jsp",
                                                                    request, response);
                        } else {
                            //Route not found; print error page
                        	String msg = MessageFormat.format(Messages.getString("ERR_TrackingPortlet.0"), new String[] {trackingId}); //$NON-NLS-1$
                            tdb.setErrorMessage(msg);
                            getPortletConfig().getContext().include("/jsp/html/TrackingDetailError.jsp", 
                                                                    request, response);
                        }
                    }
                } else {
                    //Tracking id not found; print error page
                    if (log.isLogging(Logger.ERROR)) {
                        log.text(Logger.ERROR, "doView", "Tracking record not found.");
                    }
                    String msg = MessageFormat.format(Messages.getString("ERR_TrackingPortlet.1"), new String[] {trackingId}); //$NON-NLS-1$
                    tdb.setErrorMessage(msg);
                    getPortletConfig().getContext().include("/jsp/html/TrackingDetailError.jsp", request, response);
                }
            }
        } catch (Exception exc) { 
            request.setAttribute(TRACKING_DETAIL_BEAN, tdb);
            tdb.setErrorMessage(Messages.getString("ERR_TrackingPortlet.2")); //$NON-NLS-1$
            getPortletConfig().getContext().include("/jsp/html/TrackingDetailError.jsp", request, response);
            if (log.isLogging(Logger.ERROR)) {
                log.text(Logger.ERROR, "doView", "unexpected exception", exc);
            }
        }

        if (log.isLogging(Logger.TRACE_MEDIUM)) {
            log.exit(Logger.TRACE_MEDIUM, "doView");
        }
    }

    /**
     * Process ActionEvent, according to action name
     * to set request attribute
     *
     * @param event The ActionEvent we are processing
     *
     */  
    public void actionPerformed (ActionEvent event) 
    {
        if (log.isLogging(Logger.TRACE_MEDIUM)) {
            log.entry(Logger.TRACE_MEDIUM, "actionPerformed");
        }
        String actionName = event.getActionString();

        PortletRequest request = event.getRequest();


        if (log.isLogging(Logger.TRACE_MEDIUM)) {
            log.text(Logger.TRACE_MEDIUM, "actionPerformed", "action = "
                                  + actionName + ", trackingId = " + request.getParameter(TRACKING_ID));
        }
        //An action causes the state to be modified
        ShippingUtils.setLastModified(request);

        if (actionName.equals(TRACKING_DETAILS)) {
            request.getPortletSession().setAttribute(ACTION_NAME, TRACKING_DETAILS);
            String trackingId = request.getParameter(TRACKING_ID);
            request.getPortletSession().setAttribute(TRACKING_ID, trackingId);

            //We do this as customer name is an out param 
            //in the C2A WSDL file for the tracking portlet
            //and specified to be bound to the session
            //We write the customer name in the session so it can be 
            //published by the broker in the same event cycle
            TrackingDetail td = ShippingDB.getTrackingDetail(trackingId);//in a real example don't do this again in doView - TBD
            //e.g. could store this as a request attribute to prevent repeating the work in doView - TBD
            if (td != null)
            request.getPortletSession().setAttribute(CUSTOMER_NAME, td.getCustomerName());
        } else if (actionName.equals(ROUTING_DETAILS)) {
            request.getPortletSession().setAttribute(ACTION_NAME, ROUTING_DETAILS);
            String trackingId = request.getParameter(TRACKING_ID);
            request.getPortletSession().setAttribute(TRACKING_ID, trackingId);
        } else if (actionName.equals(TRACKING_ID_ENTRY)) {
            request.getPortletSession().setAttribute(ACTION_NAME, TRACKING_ID_ENTRY);
        }
        if (log.isLogging(Logger.TRACE_MEDIUM)) {
            log.exit(Logger.TRACE_MEDIUM, "actionPerformed");
        }

    }

    public long getLastModified(PortletRequest request) {
        if (log.isLogging(Logger.TRACE_MEDIUM)) {
            log.entry(Logger.TRACE_MEDIUM, "getLastModified");
        }
        long lastModified = ShippingUtils.getLastModified(request);
        if (log.isLogging(Logger.TRACE_MEDIUM)) {
            log.exit(Logger.TRACE_MEDIUM, "getLastModified", lastModified);
        }
        return lastModified;
    }
}
