/* @copyright module */
/*                                                                            */
/*  DISCLAIMER OF WARRANTIES:                                                 */
/*  -------------------------                                                 */
/*  The following [enclosed] code is sample code created by IBM Corporation.  */
/*  This sample code is provided to you solely for the purpose of assisting   */
/*  you in the development of your applications.                              */
/*  The code is provided "AS IS", without warranty of any kind. IBM shall     */
/*  not be liable for any damages arising out of your use of the sample code, */
/*  even if they have been advised of the possibility of such damages.        */
package com.ibm.etools.portal.portletexamples.cooperative.jsr;

import java.io.IOException;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.GenericPortlet;
import javax.portlet.PortletException;
import javax.portlet.PortletRequest;
import javax.portlet.PortletURL;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;

public class AccountsPortlet 
           extends GenericPortlet
{

   private static final String PREFIX = "";
   public static final String ACTION_NAME = PREFIX + "actionName";
   public static final String ACCOUNT_DETAILS = PREFIX + "accountDetails";
   public static final String ACCOUNT_ID_ENTRY = PREFIX + "orderIdEntry";
   public static final String ACCOUNT_ID = PREFIX + "orderId";
   public static final String ACCOUNT_DETAIL_BEAN = PREFIX + "accountDetailBean";
   public static final String ACTION_NAME_PARAM = ShippingUtils.ACTION_NAME_PARAM;

	private static final String ENTRY_JSP = "AccountDetailEntry.jsp"; //$NON-NLS-1$
	private static final String VIEW_JSP = "AccountsView.jsp"; //$NON-NLS-1$
	private static final String ERROR_JSP = "AccountDetailError.jsp"; //$NON-NLS-1$

    public void doView(RenderRequest request, RenderResponse response) 
    throws PortletException,IOException
    {
        getPortletContext().log("AccountsPortlet doView entry");
		// Set the MIME type for the render response
		response.setContentType(request.getResponseContentType());
        try {
	    String action = (String) request.getPortletSession().getAttribute(ACTION_NAME);
	    AccountDetailBean adb = new AccountDetailBean();
	    request.setAttribute(ACCOUNT_DETAIL_BEAN, adb);

	    if (action == null || action.equals(ACCOUNT_ID_ENTRY)) {
	        //Show initial page
                PortletURL actionURL = ShippingUtils.createSimpleActionURL(ACCOUNT_DETAILS, response);
                adb.setActionURL(actionURL);
                getPortletContext().getRequestDispatcher(ShippingUtils.getJspFilePath(request, ENTRY_JSP)).include(request, response);
	    } else if (action.equals(ACCOUNT_DETAILS)) {

                PortletURL actionURL = ShippingUtils.createSimpleActionURL(ACCOUNT_DETAILS, response);
                adb.setActionURL(actionURL);
	        	String accountId = (String) request.getPortletSession().getAttribute(ACCOUNT_ID);
                getPortletContext().log("AccountsPortlet - account id: " + accountId);
				AccountDetail ad = ShippingDB.getAccountDetail(accountId);

                if (ad != null) {
		       		adb.setAccountDetail(ad);
                	getPortletContext().getRequestDispatcher(ShippingUtils.getJspFilePath(request, VIEW_JSP)).include(request, response);
                } else {
		    		//No match; print error page
		    		adb.setErrorMessage("account Id " + accountId + " not found.");
                    getPortletContext().getRequestDispatcher(ShippingUtils.getJspFilePath(request, ERROR_JSP)).include(request, response);
                }
		}

        } catch (Exception exc) {
           getPortletContext().log("AccountsPortlet: An error occurred", exc);

        }
   }

    public void processAction (ActionRequest request, ActionResponse response) {
            getPortletContext().log("AccountsPortlet processAction entry");

            String actionName = request.getParameter(ACTION_NAME_PARAM);
            if (actionName == null) {
                    actionName = "";
            }
            //An action causes the state to be modified
            ShippingUtils.setLastModified(request);
            if (actionName.equals(ACCOUNT_DETAILS)) {
                    request.getPortletSession().setAttribute(ACTION_NAME, ACCOUNT_DETAILS);
                    request.getPortletSession().setAttribute(ACCOUNT_ID, request.getParameter(ACCOUNT_ID));
            } else if (actionName.equals(ACCOUNT_ID_ENTRY)) {
                    request.getPortletSession().setAttribute(ACTION_NAME, ACCOUNT_ID_ENTRY);
            }
    }
    public long getLastModified(PortletRequest request) {
        return ShippingUtils.getLastModified(request);
    }

}

