/* @copyright module */
/*                                                                            */
/*  DISCLAIMER OF WARRANTIES:                                                 */
/*  -------------------------                                                 */
/*  The following [enclosed] code is sample code created by IBM Corporation.  */
/*  This sample code is provided to you solely for the purpose of assisting   */
/*  you in the development of your applications.                              */
/*  The code is provided "AS IS", without warranty of any kind. IBM shall     */
/*  not be liable for any damages arising out of your use of the sample code, */
/*  even if they have been advised of the possibility of such damages.        */
package com.ibm.etools.portal.portletexamples.cooperative.jsr;

import java.io.IOException;

import javax.naming.Context;
import javax.naming.InitialContext;
import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.GenericPortlet;
import javax.portlet.PortletConfig;
import javax.portlet.PortletException;
import javax.portlet.PortletRequest;
import javax.portlet.PortletURL;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;

import com.ibm.portal.portlet.service.PortletServiceHome;
import com.ibm.portal.propertybroker.service.PropertyBrokerService;

public class TrackingPortlet 
       extends GenericPortlet 
{

   private static final String PREFIX = "";
   public static final String ACTION_NAME = PREFIX + "actionName";
   public static final String TRACKING_DETAILS = PREFIX + "trackingDetails";
   public static final String ROUTING_DETAILS = PREFIX + "routingDetails";
   public static final String TRACKING_ID_ENTRY = PREFIX + "trackingIdEntry";
   public static final String TRACKING_ID = PREFIX + "trackingId";
   public static final String TRACKING_DETAIL_BEAN = PREFIX + "trackingDetailBean";
   public static final String CUSTOMER_NAME = PREFIX + "customerName";
   public static final String PBSERVICE = PREFIX + "pbService";
   public static final String PBSERVICEAVAILABLE = PREFIX + "pbServiceAvailable";
   public static final String ACTION_NAME_PARAM = ShippingUtils.ACTION_NAME_PARAM;

   private static final String ENTRY_JSP = "TrackingDetailEntry.jsp"; //$NON-NLS-1$
   private static final String VIEW_JSP = "TrackingView.jsp"; //$NON-NLS-1$
   private static final String ERROR_JSP = "TrackingDetailError.jsp"; //$NON-NLS-1$
   private static final String ROUTING_VIEW_JSP = "RoutingView.jsp"; //$NON-NLS-1$

   boolean pbServiceAvailable = false;
   PropertyBrokerService pbService = null;
   public void init(PortletConfig config) throws PortletException {
       super.init(config);

      try {
           Context ctx = new InitialContext();
           PortletServiceHome serviceHome = (PortletServiceHome) ctx.lookup("portletservice/com.ibm.portal.propertybroker.service.PropertyBrokerService"); 
           pbService = (PropertyBrokerService)serviceHome.getPortletService(com.ibm.portal.propertybroker.service.PropertyBrokerService.class);
           pbServiceAvailable = true;
      }catch(Throwable t) {
           getPortletContext().log("TrackingPortlet could not find property broker service!");
               }
    }

    public void doView(RenderRequest request, RenderResponse response)
    throws PortletException,IOException
    {
        getPortletContext().log("TrackingPortlet doView entry");
		// Set the MIME type for the render response
		response.setContentType(request.getResponseContentType());
        try {

	        String action = (String) request.getPortletSession().getAttribute(ACTION_NAME);
            getPortletContext().log("TrackingPortlet doView entry ActionName=" + action);
	        TrackingDetailBean tdb = new TrackingDetailBean();
	        request.setAttribute(TRACKING_DETAIL_BEAN, tdb);
                if (pbServiceAvailable == true) {
                    try {
                        tdb.setCustomerNameActive(pbService.areWiresActive(request, CUSTOMER_NAME));
                    } catch (Exception e) {
                        getPortletContext().log("OrderMonthPortlet: unexpected exception accessing property broker service", e);
                    }
                } 
	        if (action == null || action.equals(TRACKING_ID_ENTRY)) {
	            //Show initial page
                PortletURL actionURL = ShippingUtils.createSimpleActionURL(TRACKING_DETAILS, response);
                tdb.setActionURL(actionURL);
                getPortletContext().getRequestDispatcher(ShippingUtils.getJspFilePath(request, ENTRY_JSP)).include(request, response);
	        } else if (action.equals(TRACKING_DETAILS) || action.equals(ROUTING_DETAILS)) {
                PortletURL actionURL = ShippingUtils.createSimpleActionURL(TRACKING_DETAILS, response);
                tdb.setActionURL(actionURL);
                PortletURL rdActionURL = ShippingUtils.createSimpleActionURL(ROUTING_DETAILS, response);
                tdb.setRoutingDetailActionURL(rdActionURL);
	            String trackingId = (String) request.getPortletSession().getAttribute(TRACKING_ID);
                getPortletContext().log("TrackingPortlet doView: Tracking id: " + trackingId);
		        TrackingDetail td = ShippingDB.getTrackingDetail(trackingId);
		        if (td != null) {
		            tdb.setTrackingDetail(td);
		            if (action.equals(TRACKING_DETAILS))
                        getPortletContext().getRequestDispatcher(ShippingUtils.getJspFilePath(request, VIEW_JSP)).include(request, response);
		            else if (action.equals(ROUTING_DETAILS)) {
		                if (td.getRouteSegments() != null) {
                            getPortletContext().getRequestDispatcher(ShippingUtils.getJspFilePath(request, ROUTING_VIEW_JSP)).include(request, response);
		                } else {
		                    //Route not found; print error page
		                    tdb.setErrorMessage("Route for tracking Id " + trackingId + " not found.");
                            getPortletContext().getRequestDispatcher(ShippingUtils.getJspFilePath(request, ERROR_JSP)).include(request, response);
		                }
		            }
	            } else {
		            //Tracking id not found; print error page
		            tdb.setErrorMessage("Tracking Id " + trackingId + " not found.");
                    getPortletContext().getRequestDispatcher(ShippingUtils.getJspFilePath(request, ERROR_JSP)).include(request, response);
		        }
	        }
        } catch (Exception exc) {
            getPortletContext().log("TrackingPortlet doView: Exception thrown", exc);
        }
        getPortletContext().log("TrackingPortlet doView exit");
    }
    
    public void processAction (ActionRequest request, ActionResponse response) {
            getPortletContext().log("TrackingPortlet processAction entry");

            String actionName = request.getParameter(ACTION_NAME_PARAM);
            if (actionName == null) {
                    actionName = "";
            }
            //An action causes the state to be modified
            ShippingUtils.setLastModified(request);
            getPortletContext().log("TrackingPortlet processAction entry ActionName=" + actionName);
            if (actionName.equals(TRACKING_DETAILS)) {
                    request.getPortletSession().setAttribute(ACTION_NAME, TRACKING_DETAILS);
                    String trackingId = request.getParameter(TRACKING_ID);
                    request.getPortletSession().setAttribute(TRACKING_ID, trackingId);
                    getPortletContext().log("TrackingPortlet processAction TrackingId=" + trackingId);
                    //We do this as customer name is an out param 
                    //in the C2A WSDL file for the tracking portlet
                    //and specified to be bound to the session
                    //We write the customer name in the session so it can be 
                    //published by the broker in the same event cycle
                    TrackingDetail td = ShippingDB.getTrackingDetail(trackingId);//in a real example don't do this again in doView - TBD
                    //e.g. could store this as a request attribute to prevent repeating the work in doView - TBD
                    if (td != null) {
                            request.getPortletSession().setAttribute(CUSTOMER_NAME, td.getCustomerName());
                            getPortletContext().log("TrackingPortlet processAction CustomerName=" +td.getCustomerName());
                    }
            } else if (actionName.equals(ROUTING_DETAILS)) {
                    request.getPortletSession().setAttribute(ACTION_NAME, ROUTING_DETAILS);
                    String trackingId = request.getParameter(TRACKING_ID);
                    request.getPortletSession().setAttribute(TRACKING_ID, trackingId);
            } else if (actionName.equals(TRACKING_ID_ENTRY)) {
                    request.getPortletSession().setAttribute(ACTION_NAME, TRACKING_ID_ENTRY);
            }

            getPortletContext().log("TrackingPortlet processAction exit");
    }

    public long getLastModified(PortletRequest request) {
        return ShippingUtils.getLastModified(request);
    }
}
